from fastapi import FastAPI, HTTPException
from pydantic import BaseModel
import uvicorn
from google_ai.generativeai_video import main

app = FastAPI()

class VideoRequest(BaseModel):
    video_path: str

@app.post("/process_video/")
async def process_video(request: VideoRequest):
    """处理视频请求"""
    video_path = request.video_path

    # 调用 main 函数进行视频处理
    try:
        print("来一个请求")
        # 确保 main 函数是异步的
        result = await main(video_path)
        return {
            "code": 0,
            "message": "视频处理成功",
            "result": result
        }
    except Exception as e:
        raise HTTPException(status_code=500, detail=f"视频处理失败: {str(e)}")

if __name__ == "__main__":
    # proxy_url = 'http://127.0.0.1:1081'
    # os.environ["http_proxy"] = proxy_url
    # os.environ["https_proxy"] = proxy_url
    uvicorn.run(app, host="0.0.0.0", port=8080)
